@@ -19,6 +19,7 @@ import shutil
 from cogniceptshell.common import bcolors
 from cogniceptshell.common import generate_progress_bar
 from subprocess import DEVNULL
+from docker.types import LogConfig
 
 
 class AgentLifeCycle:
@@ -292,6 +293,7 @@ class AgentLifeCycle:
                 options["environment"] = args.config.config
                 options["restart_policy"] = {"Name": "unless-stopped"}
                 options["tty"] = True
+                options["log_config"] = LogConfig(type=LogConfig.types.JSON, config={'max-size': '5m'})
                 command = options.pop("command")
                 container = client.containers.run(
                     object._docker_images[container_name], command, **options)
